==> snmpstat-1.00.tar.gz: snmpstat-1.00/snmpstat.c <==
//-------------------------------------------------------
// Snmpstat ver. 1.00
// Written by Alexey Semenov
// Email: swaj_@geocities.com, alexey_semenov@hotmail.com
//-------------------------------------------------------

#include "snmpstat.h"

#define TEMP1 "/tmp/snmpstat.temp1"
#define TEMP2 "/tmp/snmpstat.temp2"
#define TEMP3 "/tmp/snmpstat.temp3"
#define TEMP4 "/tmp/snmpstat.temp4"
#define TEMP5 "/tmp/snmpstat.temp5"
#define TEMP6 "/tmp/snmpstat.temp6"
#define TEMP7 "/tmp/snmpstat.temp7"
#define TEMP8 "/tmp/snmpstat.temp8"

#define BASE_COMMAND "interfaces.ifTable.ifEntry."

#define CMD1 "ifDescr"
#define CMD2 "ifSpeed"
#define CMD3 "ifInOctets"
#define CMD4 "ifOutOctets"
#define CMD5 "ifInErrors"
#define CMD6 "ifOutErrors"
#define CMD7 "ifAdminStatus"
#define CMD8 "ifOperStatus"

//-----------------------------------

#include <sys/types.h>
#include <stdio.h>
#include <sys/time.h>
#include <errno.h>
#include <stdlib.h>
#include <unistd.h>
#include <time.h>
#include <ctype.h>
#include <string.h>

//---------------------------------------------------
   print_header () {

      char *time_string;
        time_t timv = time (0);
        time_string=ctime ( &timv );
	time_string[strlen(time_string)-1]=0;

printf ("Content-type: text/html\n\n");
printf ("<HTML>\n<HEAD>\n\t<TITLE>Interface statistics</TITLE>\n");
printf ("<META http-equiv=\"REFRESH\" content=\"");
printf (REFRESH_WWW_PAGE);
printf ("\">\n");
printf ("<meta http-equiv=\"EXPIRES\" content=\"");
printf ("%s\">\n", time_string);
printf ("<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; charset=koi8-r\">");
printf ("</HEAD>\n<BODY>\n");
}
//------------------------------

cant_connect(temp_buf)
 char *temp_buf;
 { printf ("\n<FONT SIZE=+1 COLOR=\"#ff0000\">Can't connect host %s.\n</FONT><HR>", temp_buf); }

//------------------------------

print_color (ptemp7, ptemp8)

char *ptemp7, *ptemp8;
 {
 if ( strcmp (ptemp7, "down")==0 ) printf ("BGCOLOR=\"#ffff99\">"); //YELLOW
  else if  ( (strcmp (ptemp7, "up")==0) && (strcmp (ptemp8, "up")==0) ) printf ("BGCOLOR=\"#00bb00\">"); //GREEN
   else if  ( (strcmp (ptemp7, "up")==0) && (strcmp (ptemp8, "down")==0) ) printf ("BGCOLOR=\"#ff5544\">"); //RED
      else printf ("BGCOLOR=\"#0077ee\">");
}
//--------------------------------------------------

   print_tail () {
printf ("\n</BODY>\n</HTML>");
}
//---------------------------------------------------

print_stat(temp_buf)
char *temp_buf;
{
char temp_string[256], temp_run[256];
FILE *fl1, *fl2, *fl3, *fl4, *fl5, *fl6, *fl7, *fl8;

char temp1[128], temp2[128], temp3[128], temp4[128], temp5[128], temp6[128], temp7[128], temp8[128];
char *ptemp1, *ptemp2, *ptemp3, *ptemp4, *ptemp5, *ptemp6, *ptemp7, *ptemp8;
char temp33[128];

char ptemp_zero[]="n/a";
char *p_num, *p_num1;
int valid, i;

//--------------
  unlink(TEMP1); unlink(TEMP2); unlink(TEMP3); unlink(TEMP4);
  unlink(TEMP5); unlink(TEMP6); unlink(TEMP7); unlink(TEMP8);

  printf ("<HR>"); printf ("<FONT SIZE=+1>Interface statistics for host -> </FONT> \n");
  printf ("<FONT SIZE=+3 COLOR=\"#ff0000\"><B>"); printf ("\n %s:", temp_buf); printf ("</B></FONT>");
  printf ("<P>");

  bzero ( temp_string, 256 ) ; bzero ( temp_run, 256 );

  strcpy (temp_string, SNMPWALK);  strcat (temp_string, " ");
  strcat (temp_string, temp_buf);  strcat (temp_string, " ");
  strcat (temp_string, COMMUNITY); strcat (temp_string, " "); strcat (temp_string, BASE_COMMAND);

   strcpy (temp_run, temp_string); strcat (temp_run, CMD1); strcat (temp_run, " > "); strcat (temp_run, TEMP1);

   system (temp_run);

     if ( (fl1=fopen(TEMP1, "r"))==NULL) { cant_connect(temp_buf); return; }
	fgets (temp1, 255, fl1);
	  if (strstr (temp1, BASE_COMMAND)==NULL) { cant_connect(temp_buf); fclose(fl1); return; } 
//------------
strcpy (temp_run, temp_string); strcat (temp_run, CMD2); strcat (temp_run, " > "); strcat (temp_run, TEMP2);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD3); strcat (temp_run, " > "); strcat (temp_run, TEMP3);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD4); strcat (temp_run, " > "); strcat (temp_run, TEMP4);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD5); strcat (temp_run, " > "); strcat (temp_run, TEMP5);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD6); strcat (temp_run, " > "); strcat (temp_run, TEMP6);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD7); strcat (temp_run, " > "); strcat (temp_run, TEMP7);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD8); strcat (temp_run, " > "); strcat (temp_run, TEMP8);	
  system (temp_run);

//-------------------------
  fseek (fl1, 0, SEEK_SET);
  fl2=fopen(TEMP2, "r"); fl3=fopen(TEMP3, "r"); fl4=fopen(TEMP4, "r"); fl5=fopen(TEMP5, "r");
  fl6=fopen(TEMP6, "r"); fl7=fopen(TEMP7, "r"); fl8=fopen(TEMP8, "r");
//-------------------------

  printf ("<TABLE CELLSPACING=1 CELLPADDING=0 BORDER=0 WIDTH=\"100%\">");
  printf ("<B><FONT COLOR=#000000>");

 printf ("\n<TR>");

 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("Description"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("Speed"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("InOctets"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("OutOctets"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("InErrors"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("OutErrors"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("AdminStatus"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("OperStatus"); printf ("</B></TD>");

 printf ("\n</TR>");

 valid=1;

    while ((fgets (temp1, 128, fl1))!=NULL) {

      strtok (temp1, "."); strtok (NULL, "."); strtok (NULL, "."); strtok (NULL, "."); p_num=strtok (NULL, ".");
       strtok (p_num, " ");
      strtok (NULL, "\""); ptemp1=strtok (NULL, "\"");


  fgets (temp7,128, fl7); fgets (temp8,128, fl8); fgets (temp2,128, fl2);
   strtok (temp2, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp2=strtok (NULL, "\n");
    strtok (temp7, " "); strtok (NULL, " "); ptemp7=strtok (NULL, "(");
      strtok (temp8, " "); strtok (NULL, " "); ptemp8=strtok (NULL, "(");

 if (valid==1) {
      fgets (temp3,128, fl3); fgets (temp4,128, fl4);
      fgets (temp5,128, fl5); fgets (temp6,128, fl6);

          strtok (temp4, " "); strtok (NULL, " "); ptemp4=strtok (NULL, "\n");
           strtok (temp5, " "); strtok (NULL, " "); ptemp5=strtok (NULL, "\n");
            strtok (temp6, " "); strtok (NULL, " "); ptemp6=strtok (NULL, "\n");


 } 
	strcpy (temp33, temp3);

  strtok (temp33, "."); strtok (NULL, "."); strtok (NULL, "."); strtok (NULL, "."); p_num1=strtok (NULL, ".");
    strtok (p_num1, " "); strtok (NULL," "); ptemp3=strtok (NULL, " \n");


   if ( strcmp (p_num, p_num1)==0 ) valid=1;
   else valid=0;


 printf ("\n<TR>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp1);

printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp2);
 printf ("</B></TD>");

  if (valid) {

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp3);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp4);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp5);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp6);
 printf ("</B></TD>");

 }

  else {

 for (i=0; i<4; i++) {
   printf ("<TD NOWRAP ");
   print_color ( ptemp7, ptemp8);
   printf ("<B>");
   printf ("n/a");
   printf ("</B></TD>");
  }

  }




 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp7);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp8);
 printf ("</B></TD>");

printf ("</TR>");

    }

printf ("\n</TABLE>\n");

fclose(fl1); fclose(fl2); fclose(fl3); fclose(fl4);
fclose(fl5); fclose(fl6); fclose(fl7); fclose(fl8);

}
//-------------------------------------------------------------


main(argc, argv, env)
    int     argc;
    char    *argv[];
    char    *env[];
{
char qstr[]="QUERY_STRING=host=";
char *qs;
int i;
FILE *fl0;
char buffer[128];
char *node_name;

 i=0;

  while ( (*env)!=NULL ) {
    
    if ((strncmp (*env, qstr, strlen(qstr)) == 0 ) && (strlen(*env)>14)) { qs=*env+18; i=1; }
          env++;
        }

    if (i) {
	print_header();
	print_stat(qs);
	print_tail();
	exit(0);
	}


    else {
	print_header();
	  if ( (fl0=fopen(CFG_FILE_NAME,"r"))==NULL ) {
		printf ("<FONT SIZE=+2 COLOR=\"#ff0000\">Can't open conf file");
		print_tail();
		exit(1);
		}

	  while (fgets (buffer, 127, fl0)!=NULL) {
	    node_name=strtok(buffer, " \t\n");
	    print_stat (buffer);	
	}
  print_tail();
  exit (0);
 }
}

==> snmpstat-1.0.1.tar.gz: snmpstat-1.0.1/snmpstat.c <==
//-------------------------------------------------------
// Snmpstat ver. 1.0.1
// Written by Alexey Semenov
// Email: swaj_@geocities.com, alexey_semenov@hotmail.com
//-------------------------------------------------------

#include "snmpstat.h"

#define TEMP1 "/tmp/snmpstat.temp1"
#define TEMP2 "/tmp/snmpstat.temp2"
#define TEMP3 "/tmp/snmpstat.temp3"
#define TEMP4 "/tmp/snmpstat.temp4"
#define TEMP5 "/tmp/snmpstat.temp5"
#define TEMP6 "/tmp/snmpstat.temp6"
#define TEMP7 "/tmp/snmpstat.temp7"
#define TEMP8 "/tmp/snmpstat.temp8"

#define BASE_COMMAND "interfaces.ifTable.ifEntry."

#define CMD1 "ifDescr"
#define CMD2 "ifSpeed"
#define CMD3 "ifInOctets"
#define CMD4 "ifOutOctets"
#define CMD5 "ifInErrors"
#define CMD6 "ifOutErrors"
#define CMD7 "ifAdminStatus"
#define CMD8 "ifOperStatus"

//-----------------------------------

#include <sys/types.h>
#include <stdio.h>
#include <sys/time.h>
#include <errno.h>
#include <stdlib.h>
#include <unistd.h>
#include <time.h>
#include <ctype.h>
#include <string.h>

//---------------------------------------------------
   print_header () {

      char *time_string;
        time_t timv = time (0);
        time_string=ctime ( &timv );
	time_string[strlen(time_string)-1]=0;

printf ("Content-type: text/html\n\n");
printf ("<HTML>\n<HEAD>\n\t<TITLE>Interface statistics</TITLE>\n");
printf ("<META http-equiv=\"REFRESH\" content=\"");
printf (REFRESH_WWW_PAGE);
printf ("\">\n");
printf ("<meta http-equiv=\"EXPIRES\" content=\"");
printf ("%s\">\n", time_string);
printf ("<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; charset=koi8-r\">");
printf ("\n<META http-equiv=\"Pragma\" content=\"no-cache\">\n");
printf ("<META http-equiv=\"Cache-Control\" content=\"no-cache\">\n");
printf ("</HEAD>\n<BODY>\n");
}
//------------------------------

cant_connect(temp_buf)
 char *temp_buf;
 { printf ("\n<FONT SIZE=+1 COLOR=\"#ff0000\">Can't connect host %s.\n</FONT><HR>", temp_buf); }

//------------------------------

print_color (ptemp7, ptemp8)

char *ptemp7, *ptemp8;
 {
 if ( strcmp (ptemp7, "down")==0 ) printf ("BGCOLOR=\"#ffff99\">"); //YELLOW
  else if  ( (strcmp (ptemp7, "up")==0) && (strcmp (ptemp8, "up")==0) ) printf ("BGCOLOR=\"#00bb00\">"); //GREEN
   else if  ( (strcmp (ptemp7, "up")==0) && (strcmp (ptemp8, "down")==0) ) printf ("BGCOLOR=\"#ff5544\">"); //RED
      else printf ("BGCOLOR=\"#0077ee\">");
}
//--------------------------------------------------

   print_tail () {
printf ("\n</BODY>\n</HTML>");
}
//---------------------------------------------------

print_stat(temp_buf)
char *temp_buf;
{
char temp_string[256], temp_run[256];
FILE *fl1, *fl2, *fl3, *fl4, *fl5, *fl6, *fl7, *fl8;

char temp1[128], temp2[128], temp3[128], temp4[128], temp5[128], temp6[128], temp7[128], temp8[128];
char *ptemp1, *ptemp2, *ptemp3, *ptemp4, *ptemp5, *ptemp6, *ptemp7, *ptemp8;
char temp33[128];

char ptemp_zero[]="n/a";
char *p_num, *p_num1;
int valid, i;

//--------------
  unlink(TEMP1); unlink(TEMP2); unlink(TEMP3); unlink(TEMP4);
  unlink(TEMP5); unlink(TEMP6); unlink(TEMP7); unlink(TEMP8);

  printf ("<HR>"); printf ("<FONT SIZE=+1>Interface statistics for host -> </FONT> \n");
  printf ("<FONT SIZE=+3 COLOR=\"#ff0000\"><B>"); printf ("\n %s:", temp_buf); printf ("</B></FONT>");
  printf ("<P>");

  bzero ( temp_string, 256 ) ; bzero ( temp_run, 256 );

  strcpy (temp_string, SNMPWALK);  strcat (temp_string, " ");
  strcat (temp_string, temp_buf);  strcat (temp_string, " ");
  strcat (temp_string, COMMUNITY); strcat (temp_string, " "); strcat (temp_string, BASE_COMMAND);

   strcpy (temp_run, temp_string); strcat (temp_run, CMD1); strcat (temp_run, " > "); strcat (temp_run, TEMP1);

   system (temp_run);

     if ( (fl1=fopen(TEMP1, "r"))==NULL) { cant_connect(temp_buf); return; }
	fgets (temp1, 255, fl1);
	  if (strstr (temp1, BASE_COMMAND)==NULL) { cant_connect(temp_buf); fclose(fl1); return; } 
//------------
strcpy (temp_run, temp_string); strcat (temp_run, CMD2); strcat (temp_run, " > "); strcat (temp_run, TEMP2);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD3); strcat (temp_run, " > "); strcat (temp_run, TEMP3);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD4); strcat (temp_run, " > "); strcat (temp_run, TEMP4);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD5); strcat (temp_run, " > "); strcat (temp_run, TEMP5);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD6); strcat (temp_run, " > "); strcat (temp_run, TEMP6);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD7); strcat (temp_run, " > "); strcat (temp_run, TEMP7);
  system (temp_run);
strcpy (temp_run, temp_string); strcat (temp_run, CMD8); strcat (temp_run, " > "); strcat (temp_run, TEMP8);	
  system (temp_run);

//-------------------------
  fseek (fl1, 0, SEEK_SET);
  fl2=fopen(TEMP2, "r"); fl3=fopen(TEMP3, "r"); fl4=fopen(TEMP4, "r"); fl5=fopen(TEMP5, "r");
  fl6=fopen(TEMP6, "r"); fl7=fopen(TEMP7, "r"); fl8=fopen(TEMP8, "r");
//-------------------------

  printf ("<TABLE CELLSPACING=1 CELLPADDING=0 BORDER=0 WIDTH=\"100%\">");
  printf ("<B><FONT COLOR=#000000>");

 printf ("\n<TR>");

 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("Description"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("Speed"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("InOctets"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("OutOctets"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("InErrors"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("OutErrors"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("AdminStatus"); printf ("</B></TD>");
 printf ("<TD NOWRAP BGCOLOR=\"#0077ee\"><B>");
 printf ("OperStatus"); printf ("</B></TD>");

 printf ("\n</TR>");

 valid=1;

    while ((fgets (temp1, 128, fl1))!=NULL) {

      strtok (temp1, "."); strtok (NULL, "."); strtok (NULL, "."); strtok (NULL, "."); p_num=strtok (NULL, ".");
       strtok (p_num, " ");
      strtok (NULL, "\""); ptemp1=strtok (NULL, "\"");


  fgets (temp7,128, fl7); fgets (temp8,128, fl8); fgets (temp2,128, fl2);
   strtok (temp2, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp2=strtok (NULL, "\n");
    strtok (temp7, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp7=strtok (NULL, "(");
      strtok (temp8, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp8=strtok (NULL, "(");

 if (valid==1) {
      fgets (temp3,128, fl3); fgets (temp4,128, fl4);
      fgets (temp5,128, fl5); fgets (temp6,128, fl6);

          strtok (temp4, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp4=strtok (NULL, "\n");
           strtok (temp5, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp5=strtok (NULL, "\n");
            strtok (temp6, " "); strtok (NULL, " "); strtok (NULL, " "); ptemp6=strtok (NULL, "\n");


 } 
	strcpy (temp33, temp3);

  strtok (temp33, "."); strtok (NULL, "."); strtok (NULL, "."); strtok (NULL, "."); p_num1=strtok (NULL, ".");
    strtok (p_num1, " "); strtok (NULL," "); strtok (NULL," "); ptemp3=strtok (NULL, " \n");


   if ( strcmp (p_num, p_num1)==0 ) valid=1;
   else valid=0;


 printf ("\n<TR>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp1);

printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp2);
 printf ("</B></TD>");

  if (valid) {

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp3);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp4);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp5);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp6);
 printf ("</B></TD>");

 }

  else {

 for (i=0; i<4; i++) {
   printf ("<TD NOWRAP ");
   print_color ( ptemp7, ptemp8);
   printf ("<B>");
   printf ("n/a");
   printf ("</B></TD>");
  }

  }




 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp7);
 printf ("</B></TD>");

 printf ("<TD NOWRAP ");
 print_color ( ptemp7, ptemp8);
 printf ("<B>");
 printf ("%s", ptemp8);
 printf ("</B></TD>");

printf ("</TR>");

    }

printf ("\n</TABLE>\n");

fclose(fl1); fclose(fl2); fclose(fl3); fclose(fl4);
fclose(fl5); fclose(fl6); fclose(fl7); fclose(fl8);

}
//-------------------------------------------------------------


main(argc, argv, env)
    int     argc;
    char    *argv[];
    char    *env[];
{
char qstr[]="QUERY_STRING=host=";
char *qs;
int i;
FILE *fl0;
char buffer[128];
char *node_name;

 i=0;

  while ( (*env)!=NULL ) {
    
    if ((strncmp (*env, qstr, strlen(qstr)) == 0 ) && (strlen(*env)>14)) { qs=*env+18; i=1; }
          env++;
        }

    if (i) {
	print_header();
	print_stat(qs);
	print_tail();
	exit(0);
	}


    else {
	print_header();
	  if ( (fl0=fopen(CFG_FILE_NAME,"r"))==NULL ) {
		printf ("<FONT SIZE=+2 COLOR=\"#ff0000\">Can't open conf file");
		print_tail();
		exit(1);
		}

	  while (fgets (buffer, 127, fl0)!=NULL) {
	    node_name=strtok(buffer, " \t\n");
	    print_stat (buffer);	
	}
  print_tail();
  exit (0);
 }
}
